/*
** Module   : ControlSetItem.java
** Abstract : Label-value pair container.
**
** Copyright (c) 2006-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -T- --JPRM-- ----------------Description-----------------
** 001 SIY 20060205 NEW  @24502  Created initial version
** 002 IAS 20150205 Added id and selectable fields
** 003 IAS 20150212 Renamed 'selectable' field to 'enabled' to reflect semantics
**
*/

package com.goldencode.p2j.ui;

import java.io.Serializable;

import com.goldencode.p2j.util.*;

/**
 * This class is used to transfer pairs (label and corresponding value)
 * between client and server. At client side this class also used to hold
 * values in the configuration.
 * 
 * @author  SIY
 * @version 1.0.0
 */
public class ControlSetItem
   implements Serializable
{
   /** Item id - required for correct restore of the selection after list modification. */
   private int id;

   /** Item label. */
   private character label = null;
   
   /** Item value. */
   private BaseDataType value = null;
   
   /** Item is enabled for RADIO-SET */
   private boolean enabled = true;
   
   /**
    * Constructor for the <code>ControlSetItem</code> instances.
    * 
    * @param   id
    *          Item id.
    * @param   label
    *          Item label.
    * @param   value
    *          Item value.
    */
   public ControlSetItem(int id, character label, BaseDataType value)
   {
      this.id = id;
      this.label = label;
      this.value = value;
   }

   /**
    * Constructor for the <code>ControlSetItem</code> instances.
    * 
    * @param   label
    *          Item label.
    * @param   value
    *          Item value.
    */
   public ControlSetItem(character label, BaseDataType value)
   {
      this(0, label, value);
   }
   
   /**
    * Get item label.
    * 
    * @return  Item label.
    */
   public character getLabel()
   {
      return label;
   }
   
   /**
    * Set item label.
    * 
    * @param   label
    *          New item label.
    */
   public void setLabel(character label)
   {
      this.label = label;
   }
   
   /**
    * Get item value.
    * 
    * @return  Item value.
    */
   public BaseDataType getValue()
   {
      return value;
   }
   
   /**
    * Set item value.
    * 
    * @param   value
    *          New item value.
    */
   public void setValue(BaseDataType value)
   {
      this.value = value;
   }

   /**
    * Get item id.
    * 
    * @return  Item id.
    */
   public int getId()
   {
      return id;
   }
   
   /**
    * Set item id.
    * 
    * @param   value
    *          New item id.
    */
   public void setId(int value)
   {
      this.id = value;
   }

   /**
    * Check if item is enabled.
    * 
    * @return  value of the 'enabled' flag.
    */
   public boolean isEnabled()
   {
      return enabled;
   }

   /**
    * Set item 'enabled' flag.
    * 
    * @param   selectable
    *          New value of item's 'enabled' flag.
    */
   public void setEnabled(boolean enabled)
   {
      this.enabled = enabled;
   }
}
